<?php

/**
 * @file
 * Contains function to determine previous/next node.
 */

/**
 * Returns previous/next node.
 *
 * The query is dynamically constructed. It should be:
 * select nid from {node} where status = :status
 * and type = :type and (created < :created or sticky < :sticky)
 * order by sticky desc, created desc
 * for the previous and
 * select nid from {node} where status = :status
 * and type = :type and (created > :created or sticky > :sticky)
 * order by sticky desc, created desc
 * for the next node
 *
 * @param int $node
 *   The current node
 * @param bool $back
 *   Which node to return, previous or next. Default is next
 *
 * @return mixed
 *   Node or FALSE if there are no more nodes in the sequence
 */
function _sequential_nodes_page_link($node, $back = FALSE) {

  // Dynamically construct the query depending of what node we want to get.
  $or = db_or();
  $or->condition('n.created', $node->created, $back ? '<' : '>');
  $or->condition('n.sticky', $node->sticky, $back ? '<' : '>');
  $query = db_select('node', 'n')
  ->fields('n', array('nid'))
  ->condition('n.type', $node->type)
  ->condition('n.status', $node->status)
  ->condition($or)
  ->addTag('node_access');
  // Add node_access tag to the query to avoid node access bypass.
  $query = ($back ? $query->orderBy('n.sticky', 'DESC')->orderBy('n.created', 'DESC') : $query->orderBy('n.sticky', 'ASC')->orderBy('n.created', 'ASC'));
  $next_nid = $query->execute()->fetchField();

  if ($next_nid) {
    return node_load($next_nid);
  }
  else {
    return FALSE;
  }
}
